@@ -10,10 +10,10 @@ from typing import Any, cast
 from collections import defaultdict
 
 from .interface import Plugin
-from ..common import state
+from ..common import state, CastBoolMixin
 
 
-class Extension(Plugin):
+class Extension(CastBoolMixin, Plugin):
     "Manages a layout with one centered window on top of others"
 
     workspace_info: dict[str, dict[str, Any]] = defaultdict(
@@ -37,7 +37,7 @@ class Extension(Plugin):
     async def event_activewindowv2(self, _):
         "keep track of focused client"
         if (
-            self.config.get("captive_focus")
+            self.cast_bool(self.config.get("captive_focus"))
             and self.enabled
             and state.active_window != self.main_window_addr
             and len(
