@@ -5,6 +5,7 @@ from copy import deepcopy
 from typing import Any, cast
 
 from .interface import Plugin
+from ..common import CastBoolMixin
 
 
 def trim_offset(monitors):
@@ -104,11 +105,11 @@ def build_graph(config):
     return graph
 
 
-class Extension(Plugin):  # pylint: disable=missing-class-docstring
+class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstring
     _mon_by_pat_cache: dict[str, dict] = {}
 
     async def on_reload(self):
-        if self.config.get("startup_relayout", True):
+        if self.cast_bool(self.config.get("startup_relayout"), True):
             await self.run_relayout()
 
     # Command
@@ -156,7 +157,7 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring
         "Triggers when a monitor is plugged"
         await asyncio.sleep(self.config.get("new_monitor_delay", 1.0))
 
-        if self.config.get("full_relayout", True):
+        if self.cast_bool(self.config.get("full_relayout"), True):
             await self.run_relayout()
         else:
             monitors = cast(list, await self.hyprctlJSON("monitors"))
