@@ -12,7 +12,7 @@ from aiofiles import open as aiopen
 
 from ..ipc import notify_error, get_client_props, get_focused_monitor_props
 from .interface import Plugin
-from ..common import state
+from ..common import state, CastBoolMixin
 
 DEFAULT_MARGIN = 60  # in pixels
 AFTER_SHOW_INHIBITION = 0.2  # 200ms of ignorance after a show
@@ -129,7 +129,7 @@ class Animations:  # {{{
 # }}}
 
 
-class Scratch:  # {{{
+class Scratch(CastBoolMixin):  # {{{
     "A scratchpad state including configuration & client state"
     log = logging.getLogger("scratch")
     get_client_props: Callable
@@ -161,7 +161,7 @@ class Scratch:  # {{{
 
     async def isAlive(self) -> bool:
         "is the process running ?"
-        if self.conf.get("process_tracking", True):
+        if self.cast_bool(self.conf.get("process_tracking"), True):
             path = f"/proc/{self.pid}"
             if await aios.path.exists(path):
                 async with aiopen(
@@ -322,7 +322,7 @@ class ScratchDB:  # {{{
 # }}}
 
 
-class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
+class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstring {{{
     procs: dict[str, asyncio.subprocess.Process] = {}  # pylint: disable=no-member
     scratches = ScratchDB()
 
@@ -374,7 +374,7 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
                 scratch.conf = scratches[name].conf
             else:
                 self.scratches.register(scratches[name], name)
-                is_lazy = scratches[name].conf.get("lazy", False)
+                is_lazy = self.cast_bool(scratches[name].conf.get("lazy"), False)
                 if not is_lazy:
                     scratches_to_spawn.add(name)
 
@@ -404,12 +404,8 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
                 self.log, scratch.conf.get("size", "80% 80%"), monitor
             )
 
-            position = scratch.conf.get("position")
-            if position:
-                margin_x, margin_y = convert_coords(self.log, position, monitor)
-            else:
-                margin_x = (monitor["width"] - width) // 2
-                margin_y = (monitor["height"] - height) // 2
+            margin_x = (monitor["width"] - width) // 2
+            margin_y = (monitor["height"] - height) // 2
 
             t_pos = {
                 "fromtop": f"{margin_x} -200%",
@@ -439,7 +435,7 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
 
             # skips the checks if the process isn't started (just wait)
             if is_alive or not use_proc:
-                if item.conf.get("class_match"):
+                if self.cast_bool(item.conf.get("class_match")):
                     info = await self.get_client_props(cls=item.conf.get("class"))
                 else:
                     info = await self.get_client_props(pid=item.pid)
@@ -507,7 +503,7 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
         await self._configure_windowrules(item)
         assert item
 
-        if item.conf.get("process_tracking", True):
+        if self.cast_bool(item.conf.get("process_tracking"), True):
             if not await item.isAlive():
                 self.log.info("%s is not running, starting...", uid)
                 if not await self._start_scratch(item):
@@ -627,7 +623,7 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
         class_lookup_hack = [
             s
             for s in self.scratches.getByState("respawned")
-            if s.conf.get("class_match")
+            if self.cast_bool(s.conf.get("class_match"))
         ]
         if not class_lookup_hack:
             return False
@@ -772,14 +768,21 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
                 f"alterzorder top,address:{item.full_address}",
             ]
         )
-        await self._fix_size_and_position(item, monitor)
-        if animation_type:
-            margin = item.conf.get("margin", DEFAULT_MARGIN)
-            fn = getattr(Animations, animation_type)
-            command = fn(
-                monitor, item.client_info, "address:" + item.full_address, margin
-            )
-            await self.hyprctl(command)
+        await self._fix_size(item, monitor)
+        await item.updateClientInfo()
+        if not await self._fix_position(item, monitor):
+            # position wasn't provided, use animation + margin
+            if animation_type:
+                margin = item.conf.get("margin", DEFAULT_MARGIN)
+                fn = getattr(Animations, animation_type)
+                command = fn(
+                    monitor, item.client_info, "address:" + item.full_address, margin
+                )
+                await self.hyprctl(command)
+            else:
+                await self.notify_error(
+                    f"No position and no animation provided for {item.uid}, don't know where to place it."
+                )
 
         await self.hyprctl(f"focuswindow address:{item.full_address}")
         await asyncio.sleep(0.2)  # ensure some time for events to propagate
@@ -787,17 +790,9 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
         self.scratches.clearState(item, "transition")
         item.meta["last_shown"] = time.time()
 
-    async def _fix_size_and_position(self, item, monitor):
-        "fixes the size and position of the scratchpad"
-
+    async def _fix_size(self, item, monitor):
+        "apply the `size` config parameter"
         size = item.conf.get("size")
-        position = item.conf.get("position")
-        if position:
-            x_pos, y_pos = convert_coords(self.log, position, monitor)
-            x_pos_abs, y_pos_abs = x_pos + monitor["x"], y_pos + monitor["y"]
-            await self.hyprctl(
-                f"movewindowpixel exact {x_pos_abs} {y_pos_abs},address:{item.full_address}"
-            )
         if size:
             width, height = convert_coords(self.log, size, monitor)
             max_size = item.conf.get("max_size")
@@ -808,8 +803,19 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
             await self.hyprctl(
                 f"resizewindowpixel exact {width} {height},address:{item.full_address}"
             )
-        if size or position:
-            await item.updateClientInfo()
+
+    async def _fix_position(self, item, monitor):
+        "apply the `position` config parameter"
+
+        position = item.conf.get("position")
+        if position:
+            x_pos, y_pos = convert_coords(self.log, position, monitor)
+            x_pos_abs, y_pos_abs = x_pos + monitor["x"], y_pos + monitor["y"]
+            await self.hyprctl(
+                f"movewindowpixel exact {x_pos_abs} {y_pos_abs},address:{item.full_address}"
+            )
+            return True
+        return False
 
     async def run_hide(self, uid: str, force=False, autohide=False) -> None:
         """<name> hides scratchpad "name"
@@ -839,13 +845,15 @@ class Extension(Plugin):  # pylint: disable=missing-class-docstring {{{
             )
 
         if (
-            animation_type and uid in self.focused_window_tracking
+            not autohide
+            and animation_type
+            and uid in self.focused_window_tracking
+            and self.cast_bool(scratch.conf.get("restore_focus"), True)
         ):  # focus got lost when animating
-            if not autohide and scratch.conf.get("restore_focus", True):
-                await self.hyprctl(
-                    f"focuswindow address:{self.focused_window_tracking[uid]}"
-                )
-                del self.focused_window_tracking[uid]
+            await self.hyprctl(
+                f"focuswindow address:{self.focused_window_tracking[uid]}"
+            )
+            del self.focused_window_tracking[uid]
 
     # }}}
 
